searchData={"items":[{"type":"module","title":"OpenLocationCode","doc":"Convert locations to and from Open Location Code (Plus Code).\n\nPlus Codes are short, 10-11 character codes that can be used instead\nof street addresses. The codes can be generated and decoded offline, and use\na reduced character set that minimises the chance of codes including words.\n\nCodes are able to be shortened relative to a nearby location. This means that\nin many cases, only four to seven characters of the code are needed.\nTo recover the original code, the same location is not required, as long as\na nearby location is provided.\n\nCodes represent rectangular areas rather than points, and the longer the\ncode, the smaller the area. A 10 character code represents a 13.5x13.5\nmeter area (at the equator). An 11 character code represents approximately\na 2.8x3.5 meter area.","ref":"OpenLocationCode.html"},{"type":"module","title":"Examples - OpenLocationCode","doc":"# Encode a location, default accuracy:\n    OpenLocationCode.encode(47.365590, 8.524997)\n    #=> {:ok, \"8FVC9G8F+6X\"}\n\n    # Encode a location using one stage of additional refinement:\n    OpenLocationCode.encode(47.365590, 8.524997, 11)\n    #=> {:ok, \"8FVC9G8F+6XQ\"}\n\n    # Decode a full code:\n    {:ok, code_area} = OpenLocationCode.decode(\"8FVC9G8F+6X\")\n\n    # Attempt to trim the first characters from a code:\n    OpenLocationCode.shorten(\"8FVC9G8F+6X\", 47.5, 8.5)\n    #=> {:ok, \"9G8F+6X\"}\n\n    # Recover the full code from a short code:\n    OpenLocationCode.recover_nearest(\"9G8F+6X\", 47.4, 8.6)\n    #=> {:ok, \"8FVC9G8F+6X\"}\n\n    OpenLocationCode.recover_nearest(\"8F+6X\", 47.4, 8.6)\n    #=> {:ok, \"8FVC9G8F+6X\"}","ref":"OpenLocationCode.html#module-examples"},{"type":"function","title":"OpenLocationCode.clip_latitude/1","doc":"Clip a latitude into the range -90 to 90.","ref":"OpenLocationCode.html#clip_latitude/1"},{"type":"function","title":"OpenLocationCode.decode/1","doc":"Decodes an Open Location Code into location coordinates.\n\nReturns a tuple with `:ok` and a `CodeArea` struct that includes the\ncoordinates of the bounding box - the lower left, center and upper right.\nReturns an error tuple if the code is invalid or not a full code.","ref":"OpenLocationCode.html#decode/1"},{"type":"function","title":"Examples - OpenLocationCode.decode/1","doc":"iex> OpenLocationCode.decode(\"8FVC9G8F+6X\")\n    {:ok,\n     %OpenLocationCode.CodeArea{\n       latitude_lo: 47.3655,\n       longitude_lo: 8.524875,\n       latitude_hi: 47.36562499999999,\n       longitude_hi: 8.525,\n       latitude_center: 47.365562499999996,\n       longitude_center: 8.5249375,\n       code_length: 10\n     }}\n\n    iex> OpenLocationCode.decode(\"invalid\")\n    {:error, :invalid_code}\n\n    iex> OpenLocationCode.decode(\"9G8F+6X\")  # short code\n    {:error, :full_code_expected}","ref":"OpenLocationCode.html#decode/1-examples"},{"type":"function","title":"OpenLocationCode.encode/3","doc":"Encode a location into an Open Location Code.\n\nProduces a code of the specified length, or the default length if no length\nis provided. The length determines the accuracy of the code. The default\nlength is 10 characters.","ref":"OpenLocationCode.html#encode/3"},{"type":"function","title":"Parameters - OpenLocationCode.encode/3","doc":"- `latitude` - The latitude in degrees (must be between -90 and 90)\n- `longitude` - The longitude in degrees (must be between -180 and 180)\n- `code_length` - The desired length of the code (default: 10, max: 15)","ref":"OpenLocationCode.html#encode/3-parameters"},{"type":"function","title":"Examples - OpenLocationCode.encode/3","doc":"iex> OpenLocationCode.encode(47.365590, 8.524997)\n    {:ok, \"8FVC9G8F+6X\"}\n\n    iex> OpenLocationCode.encode(47.365590, 8.524997, 11)\n    {:ok, \"8FVC9G8F+6XQ\"}","ref":"OpenLocationCode.html#encode/3-examples"},{"type":"function","title":"OpenLocationCode.encode_integers/3","doc":"Encode a location using integer values into a code.\n\nThis function takes pre-computed integer representations of latitude and\nlongitude coordinates and generates an Open Location Code.","ref":"OpenLocationCode.html#encode_integers/3"},{"type":"function","title":"Examples - OpenLocationCode.encode_integers/3","doc":"iex> OpenLocationCode.encode_integers(4736559000, 852499700, 10)\n    {:ok, \"F7F6F367+WX\"}","ref":"OpenLocationCode.html#encode_integers/3-examples"},{"type":"function","title":"OpenLocationCode.full?/1","doc":"Determines if a code is a valid full Open Location Code.\n\nNot all possible combinations of Open Location Code characters decode to\nvalid latitude and longitude values. This checks that a code is valid\nand also that the latitude and longitude values are legal.","ref":"OpenLocationCode.html#full?/1"},{"type":"function","title":"Examples - OpenLocationCode.full?/1","doc":"iex> OpenLocationCode.full?(\"8FVC9G8F+6X\")\n    true\n\n    iex> OpenLocationCode.full?(\"9G8F+6X\")  # short code\n    false\n\n    iex> OpenLocationCode.full?(\"invalid\")\n    false","ref":"OpenLocationCode.html#full?/1-examples"},{"type":"function","title":"OpenLocationCode.location_to_integers/2","doc":"Convert location in degrees into integer representations.\n\nThis is an internal helper function that converts floating-point coordinates\ninto integer values for processing.","ref":"OpenLocationCode.html#location_to_integers/2"},{"type":"function","title":"Examples - OpenLocationCode.location_to_integers/2","doc":"iex> OpenLocationCode.location_to_integers(47.365590, 8.524997)\n    {:ok, {3434139750, 1544396775}}","ref":"OpenLocationCode.html#location_to_integers/2-examples"},{"type":"function","title":"OpenLocationCode.normalize_longitude/1","doc":"Normalize a longitude into the range -180 to 180, not including 180.","ref":"OpenLocationCode.html#normalize_longitude/1"},{"type":"function","title":"OpenLocationCode.recover_nearest/3","doc":"Recover the nearest matching full code to a specified location.\n\nGiven a short code of between four and seven characters, this recovers\nthe nearest matching full code to the specified location.\n\nIf a full code is provided, it returns the code in proper capitalization.","ref":"OpenLocationCode.html#recover_nearest/3"},{"type":"function","title":"Parameters - OpenLocationCode.recover_nearest/3","doc":"- `code` - A short Open Location Code (or full code)\n- `reference_latitude` - Reference latitude in degrees\n- `reference_longitude` - Reference longitude in degrees","ref":"OpenLocationCode.html#recover_nearest/3-parameters"},{"type":"function","title":"Examples - OpenLocationCode.recover_nearest/3","doc":"iex> OpenLocationCode.recover_nearest(\"9G8F+6X\", 47.4, 8.6)\n    {:ok, \"8FVC9G8F+6X\"}\n\n    iex> OpenLocationCode.recover_nearest(\"8F+6X\", 47.4, 8.6)\n    {:ok, \"8FVCCJ8F+6X\"}\n\n    # Full codes are returned as-is (but uppercased)\n    iex> OpenLocationCode.recover_nearest(\"8fvc9g8f+6x\", 47.4, 8.6)\n    {:ok, \"8FVC9G8F+6X\"}","ref":"OpenLocationCode.html#recover_nearest/3-examples"},{"type":"function","title":"OpenLocationCode.short?/1","doc":"Determines if a code is a valid short code.\n\nA short Open Location Code is a sequence created by removing four or more\ndigits from an Open Location Code. It must include a separator character.","ref":"OpenLocationCode.html#short?/1"},{"type":"function","title":"Examples - OpenLocationCode.short?/1","doc":"iex> OpenLocationCode.short?(\"9G8F+6X\")\n    true\n\n    iex> OpenLocationCode.short?(\"8F+6X\")\n    true\n\n    iex> OpenLocationCode.short?(\"8FVC9G8F+6X\")  # full code\n    false\n\n    iex> OpenLocationCode.short?(\"invalid\")\n    false","ref":"OpenLocationCode.html#short?/1-examples"},{"type":"function","title":"OpenLocationCode.shorten/3","doc":"Remove characters from the start of an Open Location Code.\n\nThis uses a reference location to determine how many initial characters\ncan be removed from the OLC code. The closer the reference location is\nto the code's center, the more characters can be removed.\n\nReturns an error if the code cannot be shortened (e.g., if it's not a full\ncode, contains padding, or is too short).","ref":"OpenLocationCode.html#shorten/3"},{"type":"function","title":"Parameters - OpenLocationCode.shorten/3","doc":"- `code` - A full Open Location Code\n- `latitude` - Reference latitude in degrees\n- `longitude` - Reference longitude in degrees","ref":"OpenLocationCode.html#shorten/3-parameters"},{"type":"function","title":"Examples - OpenLocationCode.shorten/3","doc":"iex> OpenLocationCode.shorten(\"8FVC9G8F+6X\", 47.5, 8.5)\n    {:ok, \"9G8F+6X\"}\n\n    # Error cases\n    iex> OpenLocationCode.shorten(\"9G8F+6X\", 47.5, 8.5)  # short code\n    {:error, :full_code_expected}\n\n    iex> OpenLocationCode.shorten(\"8FVC00+\", 47.5, 8.5)  # padded code\n    {:error, :cannot_shorten_padded_codes}","ref":"OpenLocationCode.html#shorten/3-examples"},{"type":"function","title":"OpenLocationCode.valid?/1","doc":"Determines if a code is valid.\n\nTo be valid, all characters must be from the Open Location Code character\nset with at most one separator. The separator can be in any even-numbered\nposition up to the eighth digit.","ref":"OpenLocationCode.html#valid?/1"},{"type":"function","title":"Examples - OpenLocationCode.valid?/1","doc":"iex> OpenLocationCode.valid?(\"8FVC9G8F+6X\")\n    true\n\n    iex> OpenLocationCode.valid?(\"8FVC9G8F+6XQ\")\n    true\n\n    iex> OpenLocationCode.valid?(\"invalid\")\n    false\n\n    iex> OpenLocationCode.valid?(\"8FVC9G8F6X\")  # missing separator\n    false","ref":"OpenLocationCode.html#valid?/1-examples"},{"type":"module","title":"OpenLocationCode.CodeArea","doc":"Coordinates of a decoded Open Location Code.\n\nThe coordinates include the latitude and longitude of the lower left and\nupper right corners and the center of the bounding box for the area the\ncode represents.","ref":"OpenLocationCode.CodeArea.html"},{"type":"function","title":"OpenLocationCode.CodeArea.new/5","doc":"","ref":"OpenLocationCode.CodeArea.html#new/5"},{"type":"type","title":"OpenLocationCode.CodeArea.t/0","doc":"","ref":"OpenLocationCode.CodeArea.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}